=========
Materials
=========

.. warning::

    🔨 This page is under construction. 🔨


--------------------
Integration with HTM
--------------------

H-transport-materials (HTM) is a Python database of hydrogen transport properties.
Using this database will avoid making copy-pasting errors and add consistency across simulations by making sure the same properties are used.
HTM can be easily `integrated with FESTIM <https://github.com/festim-dev/FESTIM-workshop/blob/main/tasks/task08.ipynb>`_.